Blob Blame History Raw
diff -uNrp sos-3.4.orig/sos/policies/redhat.py sos-3.4/sos/policies/redhat.py
--- sos-3.4.orig/sos/policies/redhat.py	2017-08-09 22:26:42.179358997 +0000
+++ sos-3.4/sos/policies/redhat.py	2017-08-09 22:33:25.371349658 +0000
@@ -34,9 +34,9 @@ except:
 
 
 class RedHatPolicy(LinuxPolicy):
-    distro = "Red Hat"
-    vendor = "Red Hat"
-    vendor_url = "http://www.redhat.com/"
+    distro = "CentOS"
+    vendor = "CentOS"
+    vendor_url = "http://www.centos.org/"
     _redhat_release = '/etc/redhat-release'
     _tmp_dir = "/var/tmp"
     _rpmq_cmd = 'rpm -qa --queryformat "%{NAME}|%{VERSION}\\n"'
@@ -82,9 +82,9 @@ class RedHatPolicy(LinuxPolicy):
 
     @classmethod
     def check(cls):
         """This method checks to see if we are running on Red Hat. It must be
         overriden by concrete subclasses to return True when running on a
-        Fedora, RHEL or other Red Hat distribution or False otherwise."""
+        Fedora, RHEL or other CentOS distribution or False otherwise."""
         return False
 
     def _container_init(self):
@@ -132,15 +132,15 @@ class RedHatPolicy(LinuxPolicy):
     def get_local_name(self):
         return self.host_name()
 
 # Container environment variables on Red Hat systems.
 ENV_CONTAINER = 'container'
 ENV_HOST_SYSROOT = 'HOST'
 
 
 class RHELPolicy(RedHatPolicy):
-    distro = "Red Hat Enterprise Linux"
-    vendor = "Red Hat"
-    vendor_url = "https://access.redhat.com/support/"
+    distro = "CentOS Linux"
+    vendor = "CentOS"
+    vendor_url = "https://wiki.centos.org/"
     msg = _("""\
 This command will collect diagnostic and configuration \
 information from this %(distro)s system and installed \
@@ -204,7 +204,7 @@ No changes will be made to system config
 
 
 class RedHatAtomicPolicy(RHELPolicy):
-    distro = "Red Hat Atomic Host"
+    distro = "CentOS Atomic Host"
     msg = _("""\
 This command will collect diagnostic and configuration \
 information from this %(distro)s system.
@@ -82,9 +82,9 @@ class RedHatPolicy(LinuxPolicy):
     @classmethod
     def check(cls):
-        """This method checks to see if we are running on Red Hat. It must be
+        """This method checks to see if we are running on CentOS. It must be
         overriden by concrete subclasses to return True when running on a
@@ -132,15 +132,15 @@ class RedHatPolicy(LinuxPolicy):
         return self.host_name()
 
-# Container environment variables on Red Hat systems.
+# Container environment variables on CentOS systems.
 ENV_CONTAINER = 'container'
 ENV_HOST_SYSROOT = 'HOST'